<?php
/**
 * dutch language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author François Kooman <fkooman.tuxed.net>
 * @author Jack van Klaren <dokuwiki@afentoe.xs4all.nl>
 * @author Riny Heijdendael <riny@heijdendael.nl>
 * @author Koen Huybrechts <huybkoen@gmail.com>
 * @author Wouter Schoot <wouter@schoot.org>
 * @author John de Graaff <john@de-graaff.net>
 * @author Dion Nicolaas <dion@nicolaas.net>
 * @author Danny Rotsaert <danny.rotsaert@edpnet.be>
 * @author Matthias Carchon <webmaster@c-mattic.be>
 * @author Marijn Hofstra <hofstra.m@gmail.com>
 * @author Timon Van Overveldt <timonvo@gmail.com>
 * @author Jeroen
 * @author Ricardo Guijt <ricardoguijt@gmail.com>
 * @author Gerrit <klapinklapin@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Pagina aanpassen';
$lang['btn_source']            = 'Toon broncode';
$lang['btn_show']              = 'Toon pagina';
$lang['btn_create']            = 'Maak deze pagina aan';
$lang['btn_search']            = 'Zoeken';
$lang['btn_save']              = 'Opslaan';
$lang['btn_preview']           = 'Voorbeeld';
$lang['btn_top']               = 'Terug naar boven';
$lang['btn_newer']             = '<< recenter';
$lang['btn_older']             = 'ouder >>';
$lang['btn_revs']              = 'Oude revisies';
$lang['btn_recent']            = 'Recente aanpassingen';
$lang['btn_upload']            = 'Upload';
$lang['btn_cancel']            = 'Annuleren';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Aanpassen';
$lang['btn_login']             = 'Inloggen';
$lang['btn_logout']            = 'Uitloggen';
$lang['btn_admin']             = 'Beheer';
$lang['btn_update']            = 'Bijwerken';
$lang['btn_delete']            = 'Verwijder';
$lang['btn_back']              = 'Terug';
$lang['btn_backlink']          = 'Referenties';
$lang['btn_backtomedia']       = 'Terug naar Bestandsselectie';
$lang['btn_subscribe']         = 'Inschrijven wijzigingen';
$lang['btn_profile']           = 'Profiel aanpassen';
$lang['btn_reset']             = 'Wissen';
$lang['btn_resendpwd']         = 'Nieuw wachtwoord bepalen';
$lang['btn_draft']             = 'Bewerk concept';
$lang['btn_recover']           = 'Herstel concept';
$lang['btn_draftdel']          = 'Verwijder concept';
$lang['btn_revert']            = 'Herstellen';
$lang['btn_register']          = 'Registreren';
$lang['btn_apply']             = 'Toepassen';
$lang['btn_media']             = 'Mediabeheerder';
$lang['loggedinas']            = 'Ingelogd als';
$lang['user']                  = 'Gebruikersnaam';
$lang['pass']                  = 'Wachtwoord';
$lang['newpass']               = 'Nieuw wachtwoord';
$lang['oldpass']               = 'Bevestig huidig wachtwoord';
$lang['passchk']               = 'nogmaals';
$lang['remember']              = 'Bewaar';
$lang['fullname']              = 'Volledige naam';
$lang['email']                 = 'E-mail';
$lang['profile']               = 'Gebruikersprofiel';
$lang['badlogin']              = 'Sorry, gebruikersnaam of wachtwoord onjuist';
$lang['minoredit']             = 'Kleine wijziging';
$lang['draftdate']             = 'Concept automatisch opgeslagen op';
$lang['nosecedit']             = 'De pagina is tussentijds veranderd, sectie-informatie was verouderd, volledige pagina geladen.';
$lang['regmissing']            = 'Vul alle velden in';
$lang['reguexists']            = 'Er bestaat al een gebruiker met deze loginnaam.';
$lang['regsuccess']            = 'De gebruiker is aangemaakt. Het wachtwoord is per e-mail verzonden.';
$lang['regsuccess2']           = 'De gebruiker is aangemaakt.';
$lang['regmailfail']           = 'Het lijkt erop dat het sturen van de wachtwoordmail mislukt is. Neem contact op met de beheerder!';
$lang['regbadmail']            = 'Het opgegeven e-mailadres lijkt ongeldig - als je denkt dat dit niet klopt neem dan contact op met de beheerder.';
$lang['regbadpass']            = 'De twee ingevoerde wachtwoorden zijn niet identiek. Probeer het nog eens.';
$lang['regpwmail']             = 'Je DokuWiki wachtwoord';
$lang['reghere']               = 'Je hebt nog geen account? Vraag er eentje aan';
$lang['profna']                = 'Deze wiki ondersteunt geen profielwijzigingen';
$lang['profnochange']          = 'Geen wijzigingen, niets gedaan';
$lang['profnoempty']           = 'Een lege gebruikersnaam of e-mailadres is niet toegestaan';
$lang['profchanged']           = 'Gebruikersprofiel succesvol aangepast';
$lang['pwdforget']             = 'Je wachtwoord vergeten? Vraag een nieuw wachtwoord aan';
$lang['resendna']              = 'Deze wiki ondersteunt het verzenden van wachtwoorden niet';
$lang['resendpwd']             = 'Nieuw wachtwoord bepalen voor';
$lang['resendpwdmissing']      = 'Sorry, je moet alle velden invullen.';
$lang['resendpwdnouser']       = 'Sorry, we kunnen deze gebruikersnaam niet vinden in onze database.';
$lang['resendpwdbadauth']      = 'Sorry, deze authentiecatiecode is niet geldig. Controleer of je de volledige bevestigings-link hebt gebruikt.';
$lang['resendpwdconfirm']      = 'Een bevestigingslink is per e-mail verzonden.';
$lang['resendpwdsuccess']      = 'Je nieuwe wachtwoord is per e-mail verzonden.';
$lang['license']               = 'Tenzij anders vermeld valt de inhoud van deze wiki onder de volgende licentie:';
$lang['licenseok']             = 'Let op: Door deze pagina aan te passen geef je de inhoud vrij onder de volgende licentie:';
$lang['searchmedia']           = 'Bestandsnaam zoeken:';
$lang['searchmedia_in']        = 'Zoek in %s';
$lang['txt_upload']            = 'Selecteer een bestand om te uploaden';
$lang['txt_filename']          = 'Vul nieuwe naam in (optioneel)';
$lang['txt_overwrt']           = 'Overschrijf bestaand bestand';
$lang['maxuploadsize']         = 'Max %s per bestand';
$lang['lockedby']              = 'Momenteel in gebruik door';
$lang['lockexpire']            = 'Exclusief gebruiksrecht vervalt op';
$lang['js']['willexpire']      = 'Je exclusieve gebruiksrecht voor het aanpassen van deze pagina verloopt over een minuut.\nKlik op de Voorbeeld-knop om het exclusieve gebruiksrecht te verlengen.';
$lang['js']['notsavedyet']     = 'Nog niet bewaarde wijzigingen zullen verloren gaan.
Weet je zeker dat je wilt doorgaan?';
$lang['js']['searchmedia']     = 'Zoek naar bestanden';
$lang['js']['keepopen']        = 'Houd scherm open bij selectie';
$lang['js']['hidedetails']     = 'Verberg details';
$lang['js']['mediatitle']      = 'Linkinstellingen';
$lang['js']['mediadisplay']    = 'Linktype';
$lang['js']['mediaalign']      = 'Uitlijning';
$lang['js']['mediasize']       = 'Afbeeldingsomvang';
$lang['js']['mediatarget']     = 'Linkdoel';
$lang['js']['mediaclose']      = 'Sluiten';
$lang['js']['mediainsert']     = 'Invoegen';
$lang['js']['mediadisplayimg'] = 'De afbeelding weergeven';
$lang['js']['mediadisplaylnk'] = 'Alleen de link weergeven';
$lang['js']['mediasmall']      = 'Kleine versie';
$lang['js']['mediamedium']     = 'Middelgrote versie';
$lang['js']['medialarge']      = 'Grote versie';
$lang['js']['mediaoriginal']   = 'Originele versie';
$lang['js']['medialnk']        = 'Link naar detailpagina';
$lang['js']['mediadirect']     = 'Directe link naar origineel';
$lang['js']['medianolnk']      = 'Geen link';
$lang['js']['medianolink']     = 'Link niet naar de afbeelding';
$lang['js']['medialeft']       = 'Afbeelding links uitlijnen';
$lang['js']['mediaright']      = 'Afbeelding rechts uitlijnen';
$lang['js']['mediacenter']     = 'Afbeelding centreren';
$lang['js']['medianoalign']    = 'Geen uitlijning gebruiken';
$lang['js']['nosmblinks']      = 'Linken naar Windows shares werkt alleen in Microsoft Internet Explorer.
Je kan de link wel kopiëren en plakken.';
$lang['js']['linkwiz']         = 'Linkwizard';
$lang['js']['linkto']          = 'Link naar:';
$lang['js']['del_confirm']     = 'Item(s) verwijderen?';
$lang['js']['restore_confirm'] = 'Werkelijk deze versie terugzetten?';
$lang['js']['media_diff']      = 'Verschillen bekijken:';
$lang['js']['media_diff_both'] = 'Naast elkaar';
$lang['js']['media_diff_opacity'] = 'Doorschijnend';
$lang['js']['media_diff_portions'] = 'Swipe';
$lang['js']['media_select']    = 'Selecteer bestanden';
$lang['js']['media_upload_btn'] = 'Uploaden';
$lang['js']['media_done_btn']  = 'Klaar';
$lang['js']['media_drop']      = 'Sleep bestanden hierheen om ze te uploaden';
$lang['js']['media_cancel']    = 'Verwijderen';
$lang['js']['media_overwrt']   = 'Bestaande bestanden overschrijven';
$lang['rssfailed']             = 'Er is een fout opgetreden bij het ophalen van de feed: ';
$lang['nothingfound']          = 'Er werd niets gevonden.';
$lang['mediaselect']           = 'Bestandsselectie';
$lang['fileupload']            = 'Bestandsupload';
$lang['uploadsucc']            = 'Upload geslaagd';
$lang['uploadfail']            = 'Upload mislukt. Misschien verkeerde permissies?';
$lang['uploadwrong']           = 'Upload mislukt. Deze bestandsextensie is verboden!';
$lang['uploadexist']           = 'Bestand bestaat reeds. Er is niets gewijzigd.';
$lang['uploadbadcontent']      = 'Het geüploade bestand heeft niet de bestandsextensie %s.';
$lang['uploadspam']            = 'De upload is geblokkeerd door de spam blacklist.';
$lang['uploadxss']             = 'De upload is geblokkeerd wegens mogelijk onveilige inhoud.';
$lang['uploadsize']            = 'Het geüploade bestand is te groot. (max. %s)';
$lang['deletesucc']            = 'Het bestand "%s" is verwijderd.';
$lang['deletefail']            = '"%s" kan niet worden verwijderd - controleer permissies.';
$lang['mediainuse']            = 'Het bestand "%s" is niet verwijderd - het is nog in gebruik.';
$lang['namespaces']            = 'Namespaces';
$lang['mediafiles']            = 'Beschikbare bestanden in';
$lang['accessdenied']          = 'U heeft geen toegang tot deze pagina.';
$lang['mediausage']            = 'Gebruik de volgende syntax om aan het bestand te refereren:';
$lang['mediaview']             = 'Bekijk het orginele bestand';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Upload een bestand naar de huidige namespace. Om een subnamespace aan te maken, laat je die voorafgaan aan de bestandsnaam bij "Upload als", gescheiden door een dubbele punt.';
$lang['mediaextchange']        = 'Bestandsextensie veranderd van .%s naar .%s!';
$lang['reference']             = 'Referenties voor';
$lang['ref_inuse']             = 'Het bestand kan niet worden verwijderd omdat het nog in gebruik is op de volgende pagina\'s:';
$lang['ref_hidden']            = 'Enkele referenties staan op pagina\'s waarvoor je geen leesrechten hebt';
$lang['hits']                  = 'Hits';
$lang['quickhits']             = 'Overeenkomende paginanamen';
$lang['toc']                   = 'Inhoud';
$lang['current']               = 'huidige';
$lang['yours']                 = 'Jouw versie';
$lang['diff']                  = 'Toon verschillen met huidige revisie';
$lang['diff2']                 = 'Toon verschillen tussen geselecteerde revisies';
$lang['difflink']              = 'Link naar deze vergelijking';
$lang['diff_type']             = 'Bekijk verschillen:';
$lang['diff_inline']           = 'Inline';
$lang['diff_side']             = 'Zij aan zij';
$lang['line']                  = 'Regel';
$lang['breadcrumb']            = 'Spoor';
$lang['youarehere']            = 'Je bent hier';
$lang['lastmod']               = 'Laatst gewijzigd';
$lang['by']                    = 'door';
$lang['deleted']               = 'verwijderd';
$lang['created']               = 'aangemaakt';
$lang['restored']              = 'oude revisie hersteld';
$lang['external_edit']         = 'Externe bewerking';
$lang['summary']               = 'Samenvatting wijziging';
$lang['noflash']               = 'De <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> is vereist om de pagina te kunnen weergeven.';
$lang['download']              = 'Download fragment';
$lang['tools']                 = 'Hulpmiddelen';
$lang['user_tools']            = 'Gebruikershulpmiddelen';
$lang['site_tools']            = 'Site-hulpmiddelen';
$lang['page_tools']            = 'Paginahulpmiddelen';
$lang['skip_to_content']       = 'spring naar tekst';
$lang['sidebar']               = 'Zijbalk';
$lang['mail_newpage']          = 'pagina toegevoegd:';
$lang['mail_changed']          = 'pagina aangepast:';
$lang['mail_subscribe_list']   = 'Pagina\'s veranderd in namespace:';
$lang['mail_new_user']         = 'nieuwe gebruiker:';
$lang['mail_upload']           = 'bestand geüpload:';
$lang['changes_type']          = 'Bekijk wijzigingen van';
$lang['pages_changes']         = 'Pagina\'s';
$lang['media_changes']         = 'Mediabestanden';
$lang['both_changes']          = 'Zowel pagina\'s als mediabestanden';
$lang['qb_bold']               = 'Vette tekst';
$lang['qb_italic']             = 'Cursieve tekst';
$lang['qb_underl']             = 'Onderstreepte tekst';
$lang['qb_code']               = 'Code tekst';
$lang['qb_strike']             = 'Doorgestreepte tekst';
$lang['qb_h1']                 = 'Niveau 1 kop';
$lang['qb_h2']                 = 'Niveau 2 kop';
$lang['qb_h3']                 = 'Niveau 3 kop';
$lang['qb_h4']                 = 'Niveau 4 kop';
$lang['qb_h5']                 = 'Niveau 5 kop';
$lang['qb_h']                  = 'Koptekst';
$lang['qb_hs']                 = 'Kies koptekst';
$lang['qb_hplus']              = 'Hogere koptekst';
$lang['qb_hminus']             = 'Lagere koptekst';
$lang['qb_hequal']             = 'Koptekst op zelfde niveau';
$lang['qb_link']               = 'Interne link';
$lang['qb_extlink']            = 'Externe link';
$lang['qb_hr']                 = 'Horizontale lijn';
$lang['qb_ol']                 = 'Geordende lijst';
$lang['qb_ul']                 = 'Ongeordende lijst';
$lang['qb_media']              = 'Voeg plaatjes en andere bestanden toe';
$lang['qb_sig']                = 'Handtekening invoegen';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Speciale tekens';
$lang['upperns']               = 'Spring naar bovenliggende namespace';
$lang['admin_register']        = 'Nieuwe gebruiker toevoegen';
$lang['metaedit']              = 'Metadata wijzigen';
$lang['metasaveerr']           = 'Schrijven van metadata mislukt';
$lang['metasaveok']            = 'Metadata bewaard';
$lang['img_backto']            = 'Terug naar';
$lang['img_title']             = 'Titel';
$lang['img_caption']           = 'Bijschrift';
$lang['img_date']              = 'Datum';
$lang['img_fname']             = 'Bestandsnaam';
$lang['img_fsize']             = 'Grootte';
$lang['img_artist']            = 'Fotograaf';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Formaat';
$lang['img_camera']            = 'Camera';
$lang['img_keywords']          = 'Trefwoorden';
$lang['img_width']             = 'Breedte';
$lang['img_height']            = 'Hoogte';
$lang['img_manager']           = 'In mediabeheerder bekijken';
$lang['subscr_subscribe_success'] = '%s is ingeschreven voor %s';
$lang['subscr_subscribe_error'] = 'Fout bij inschrijven van %s voor %s';
$lang['subscr_subscribe_noaddress'] = 'Er is geen emailadres geassocieerd met uw account, u kunt daardoor niet worden ingeschreven.';
$lang['subscr_unsubscribe_success'] = '%s is nu uitgeschreven bij %s.';
$lang['subscr_unsubscribe_error'] = 'Fout bij uitschrijven van %s bij %s.';
$lang['subscr_already_subscribed'] = '%s is reeds ingeschreven bij %s.';
$lang['subscr_not_subscribed'] = '%s is niet ingeschreven bij %s.';
$lang['subscr_m_not_subscribed'] = 'Je bent momenteel niet ingeschreven bij de huidige pagina of namespace.';
$lang['subscr_m_new_header']   = 'Inschrijving toevoegen';
$lang['subscr_m_current_header'] = 'Huidige inschrijvingen';
$lang['subscr_m_unsubscribe']  = 'Uitschrijven';
$lang['subscr_m_subscribe']    = 'Inschrijven';
$lang['subscr_m_receive']      = 'Ontvang';
$lang['subscr_style_every']    = 'Email bij iedere wijziging';
$lang['subscr_style_digest']   = 'Samenvattings-email met wijzigingen per pagina (elke %.2f dagen)';
$lang['subscr_style_list']     = 'Lijst van veranderde pagina\'s sinds laatste email (elke %.2f dagen)';
$lang['authmodfailed']         = 'Ongeldige gebruikersauthenticatie-configuratie. Informeer de wikibeheerder.';
$lang['authtempfail']          = 'Gebruikersauthenticatie is tijdelijk niet beschikbaar. Als deze situatie zich blijft voordoen, informeer dan de wikibeheerder.';
$lang['authpwdexpire']         = 'Je wachtwoord verloopt in %d dagen, je moet het binnenkort veranderen';
$lang['i_chooselang']          = 'Kies je taal';
$lang['i_installer']           = 'DokuWiki Installer';
$lang['i_wikiname']            = 'Wikinaam';
$lang['i_enableacl']           = 'ACLs inschakelen (aanbevolen)';
$lang['i_superuser']           = 'Superuser';
$lang['i_problems']            = 'De installer vond problemen, hieronder aangegeven. Verhelp deze voor je doorgaat.';
$lang['i_modified']            = 'Uit veiligheidsoverwegingen werkt dit script alleen met nieuwe en onveranderde DokuWiki-installaties. Pak de bestanden opnieuw uit of raadpleeg de <a href="http://dokuwiki.org/install">Dokuwiki installatie-instructies</a>';
$lang['i_funcna']              = 'PHP functie <code>%s</code> is niet beschikbaar. Wellicht heeft je hosting provider deze uitgeschakeld?';
$lang['i_phpver']              = 'PHP-versie <code>%s</code> is lager dan de vereiste <code>%s</code>. Upgrade PHP.';
$lang['i_permfail']            = '<code>%s</code> is niet schrijfbaar voor DokuWiki. Pas de permissie-instellingen van deze directory aan.';
$lang['i_confexists']          = '<code>%s</code> bestaat reeds';
$lang['i_writeerr']            = 'Niet mogelijk om <code>%s</code> aan te maken. Controleer de directory/bestandspermissies en maak het bestand handmatig aan.';
$lang['i_badhash']             = 'Onbekende of aangepaste dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - onjuiste of lege waarde';
$lang['i_success']             = 'De configuratie is succesvol afgerond. Je kunt nu het bestand install.php verwijderen. Ga naar <a href="doku.php">je nieuwe DokuWiki</a>.';
$lang['i_failure']             = 'Fouten deden zich voor tijdens het schrijven naar de configuratiebestanden. Pas deze aan voor je gebruik kunt maken van <a href="doku.php">je nieuwe DokuWiki</a>.';
$lang['i_policy']              = 'Initieel ACL-beleid';
$lang['i_pol0']                = 'Open wiki (lezen, schrijven, uploaden voor iedereen)';
$lang['i_pol1']                = 'Publieke wiki (lezen voor iedereen, schrijven en uploaden voor geregistreerde gebruikers)';
$lang['i_pol2']                = 'Besloten wiki (lezen, schrijven en uploaden alleen voor geregistreerde gebruikers)';
$lang['i_retry']               = 'Opnieuw';
$lang['i_license']             = 'Kies a.u.b. een licentie die u voor uw inhoud wilt gebruiken:';
$lang['recent_global']         = 'Je bekijkt momenteel de wijzigingen binnen de <b>%s</b> namespace. Je kunt ook de <a href="%s">recente wijzigingen van de hele wiki</a> bekijken.';
$lang['years']                 = '%d jaar geleden';
$lang['months']                = '%d maand geleden';
$lang['weeks']                 = '%d weken geleden';
$lang['days']                  = '%d dagen geleden';
$lang['hours']                 = '%d uren geleden';
$lang['minutes']               = '%d minuten geleden';
$lang['seconds']               = '%d seconden geleden';
$lang['wordblock']             = 'Uw wijziging is niet opgeslagen omdat deze niet-toegestane tekst bevat (spam).';
$lang['media_uploadtab']       = 'Uploaden';
$lang['media_searchtab']       = 'Zoeken';
$lang['media_file']            = 'Bestand';
$lang['media_viewtab']         = 'Beeld';
$lang['media_edittab']         = 'Bewerken';
$lang['media_historytab']      = 'Geschiedenis';
$lang['media_list_thumbs']     = 'Miniatuurweergaven';
$lang['media_list_rows']       = 'Regels';
$lang['media_sort_name']       = 'Naam';
$lang['media_sort_date']       = 'Datum';
$lang['media_namespaces']      = 'Kies namespace';
$lang['media_files']           = 'Bestanden in %s';
$lang['media_upload']          = 'Upload naar %s';
$lang['media_search']          = 'Zoeken in %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s bij %s';
$lang['media_edit']            = '%s bewerken';
$lang['media_history']         = 'Geschiedenis van %s';
$lang['media_meta_edited']     = 'Metagegevens bewerkt';
$lang['media_perm_read']       = 'Sorry, u heeft niet voldoende rechten om bestanden te lezen.';
$lang['media_perm_upload']     = 'Sorry, u heeft niet voldoende rechten om bestanden te uploaden.';
$lang['media_update']          = 'Upload nieuwe versie';
$lang['media_restore']         = 'Deze versie terugzetten';
